Name:           ocaml-cryptokit
Version:        1.11
Release:        %mkrel 11
Summary:        OCaml library of cryptographic and hash functions
License:        LGPLv2 with linking exception
Group:          Development/OCaml
URL:            http://forge.ocamlcore.org/projects/cryptokit/
Source0:        http://forge.ocamlcore.org/frs/download.php/1618/cryptokit-%{version}.tar.gz

BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-ocamlbuild
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-zarith-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(ncurses)

%description
The Cryptokit library for Objective Caml provides a variety of
cryptographic primitives that can be used to implement cryptographic
protocols in security-sensitive applications. The primitives provided
include:

* Symmetric-key cryptography: AES, DES, Triple-DES, ARCfour, in ECB,
  CBC, CFB and OFB modes.
* Public-key cryptography: RSA encryption and signature; Diffie-Hellman
  key agreement.
* Hash functions and MACs: SHA-1, SHA-256, RIPEMD-160, MD5, and MACs
  based on AES and DES.
* Random number generation.
* Encodings and compression: base 64, hexadecimal, Zlib compression. 

Additional ciphers and hashes can easily be used in conjunction with
the library. In particular, basic mechanisms such as chaining modes,
output buffering, and padding are provided by generic classes that can
easily be composed with user-provided ciphers. More generally, the
library promotes a "Lego"-like style of constructing and composing
transformations over character streams.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-zarith-devel
Requires:       pkgconfig(zlib)

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n cryptokit-%{version}

%build
ocaml setup.ml -debug -configure --libdir %{_libdir}
ocaml setup.ml -build

%check
# This opens /dev/random but never reads from it.
ocaml setup.ml -test

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR
mkdir -p %{buildroot}%{_libdir}/ocaml/cryptokit
mkdir -p %{buildroot}%{_libdir}/ocaml/stublibs
ocaml setup.ml -debug -install 

%files
%doc README.txt LICENSE.txt AUTHORS.txt Changes
%dir %{_libdir}/ocaml/cryptokit
%{_libdir}/ocaml/cryptokit/META
%{_libdir}/ocaml/cryptokit/*.cma
%{_libdir}/ocaml/cryptokit/*.cmi
%{_libdir}/ocaml/cryptokit/*.cmxs
%{_libdir}/ocaml/stublibs/*.so*

%files devel
%{_libdir}/ocaml/cryptokit/*.annot
%{_libdir}/ocaml/cryptokit/*.a
%{_libdir}/ocaml/cryptokit/*.cmt
%{_libdir}/ocaml/cryptokit/*.cmti
%{_libdir}/ocaml/cryptokit/*.cmxa
%{_libdir}/ocaml/cryptokit/*.cmx
%{_libdir}/ocaml/cryptokit/*.mli


%changelog
* Sun Jan 10 2021 pterjan <pterjan> 1.11-11.mga8
+ Revision: 1670439
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.11-10.mga8
+ Revision: 1551352
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.11-9.mga8
+ Revision: 1544391
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 tv <tv> 1.11-8.mga8
+ Revision: 1483001
- rebuild for ocaml-4.10

* Tue Oct 23 2018 pterjan <pterjan> 1.11-7.mga7
+ Revision: 1324396
- Rebuild for ocaml 4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 1.11-6.mga7
+ Revision: 1299856
- Mageia 7 Mass Rebuild

* Sun Mar 25 2018 daviddavid <daviddavid> 1.11-5.mga7
+ Revision: 1212408
- rebuild for new ocaml-zarith 1.7

* Sun Nov 26 2017 tv <tv> 1.11-4.mga7
+ Revision: 1179794
+ rebuild (emptylog)

* Sun Nov 26 2017 tv <tv> 1.11-3.mga7
+ Revision: 1179793
- BR ocaml-ocamlbuild
- rebuild for new ocaml

* Fri Oct 13 2017 daviddavid <daviddavid> 1.11-2.mga7
+ Revision: 1171556
- add missing requires on ocaml-zarith-devel

* Thu Oct 12 2017 daviddavid <daviddavid> 1.11-1.mga7
+ Revision: 1171347
- new version: 1.11 (fix upstream for uint32_t)

* Mon Sep 26 2016 pterjan <pterjan> 1.9-6.mga6
+ Revision: 1056320
- Rebuild for fix in ocaml

* Fri Feb 12 2016 umeabot <umeabot> 1.9-5.mga6
+ Revision: 956325
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.9-4.mga5
+ Revision: 738939
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.9-3.mga5
+ Revision: 683014
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.9-2.mga4
+ Revision: 534958
- Mageia 4 Mass Rebuild

* Mon Sep 16 2013 malo <malo> 1.9-1.mga4
+ Revision: 480292
- update to 1.9

* Tue Sep 10 2013 blue_prawn <blue_prawn> 1.6-7.mga4
+ Revision: 477220
- rebuild for ocaml-4.01.0

* Sat Jan 12 2013 umeabot <umeabot> 1.6-6.mga3
+ Revision: 361252
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 malo <malo> 1.6-5.mga3
+ Revision: 324104
- rebuild for new ocaml

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.6-4.mga3
+ Revision: 301442
- build requires ocaml-compiler
- rebuild for ocaml-4.00.0
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.6-2.mga3
+ Revision: 300059
- new rpm group for ocaml

* Mon Jun 25 2012 blue_prawn <blue_prawn> 1.6-1.mga3
+ Revision: 263592
- updated to last version 1.6

* Mon Apr 09 2012 malo <malo> 1.5-2.mga2
+ Revision: 229843
- adding missing requires to zlib-devel

* Sun Oct 23 2011 malo <malo> 1.5-1.mga2
+ Revision: 157506
- missing Buildrequires on ncurses-devel
- missing BuildRequires to ocaml-findlib
- removing BuildRoot and unused BuildRequires
- imported package ocaml-cryptokit

